//---------------------------------------------------------------------------
// Copyright 1997 Andreas Huennebeck
//
// $Source: /home/ah/CvsTree/daten/src/include/AH/Etech/PickUp.h,v $
// $Id: PickUp.h,v 1.2 2002/12/30 15:15:33 ah Exp $
//
//---------------------------------------------------------------------------

#ifndef ETECH_PICKUP_H	// prevent multiple includes
#define ETECH_PICKUP_H

// --- necessary includes ---

#include <AH/Config/Platform.h>
#include <AH/Etech/Impedance.h>
#include <AH/Etech/Resistor.h>
#include <AH/Etech/Capacitor.h>
#include <AH/Etech/Inductor.h>

USING_NAMESPACE(Ah)
BEGIN_NAMESPACE(Ah)

// --- forward declarations ---

// --- types and classes ---


/// represents a pickup of a record player
/**
 {\tt PickUp} represents a pickup of a record player.
 */
class PickUp
{
  private:
    Resistor    Rmm;
    Inductor    Lmm;
    Capacitor   Cmm;
    const char*	Name;	// name of pickup

  public:
    /// default constructor
    PickUp();
    /// constructor
    PickUp(const char* name, Dbl r, Dbl l, Dbl c);
    /// copy constructor
    PickUp(const PickUp& op);
    /// destructor:
    virtual ~PickUp();

    /// return name of pickup
    const char* getName() const { return Name; }

    /// get attenuation at frequency {\tt f} for load impedanze {\tt z}
    virtual Cplx getAtt(Dbl f, const Impedance& z);

    /// assign operator
    const PickUp& operator = (const PickUp& op);

}; // class PickUp


/// Ortofon 540 MK2 (example supplied by Frank Klemm in drmh).
class PickUpOrtofon540mk2: public PickUp
{
 public:
    /// default constructor
    PickUpOrtofon540mk2() : PickUp("Ortofon 540 MK2", 1000, 0.58, 1e-18) {}
    /// destructor:
    virtual ~PickUpOrtofon540mk2() {}
};


/// Van den Hul DDT II Special (data supplied by Frank Klemm).
class PickUpVdhDDT2Special: public PickUp
{
 public:
    /// default constructor
    PickUpVdhDDT2Special() : PickUp("Van den Hul DDT II Special", 
				    17.5, 0.0159e-3, 1e-18) {}
    /// destructor:
    virtual ~PickUpVdhDDT2Special() {}
};


/// Van den Hul Frog Copper (data supplied by Frank Klemm).
class PickUpVdhFrogCopper: public PickUp
{
 public:
    /// default constructor
    PickUpVdhFrogCopper() : PickUp("Van den Hul Frog Copper", 
				    24, 0.0497e-3, 1e-18) {}
    /// destructor:
    virtual ~PickUpVdhFrogCopper() {}
};


/// Van den Hul Black Beauty SPX (data supplied by Frank Klemm).
class PickUpVdhBlackBeautySPX: public PickUp
{
 public:
    /// default constructor
    PickUpVdhBlackBeautySPX() : PickUp("Van den Hul Black Beauty SPX", 
				    15.7, 0.0198e-3, 1e-18) {}
    /// destructor:
    virtual ~PickUpVdhBlackBeautySPX() {}
};


/// Van den Hul The Colibri XGP (data supplied by Frank Klemm).
class PickUpVdhColibriXGP: public PickUp
{
 public:
    /// default constructor
    PickUpVdhColibriXGP() : PickUp("Van den Hul The Colibri XGP", 
				    52.3, 0.0648e-3, 1e-18) {}
    /// destructor:
    virtual ~PickUpVdhColibriXGP() {}
};


/// Clearaudio Alpha Wood (data supplied by Frank Klemm).
class PickUpClearaudioAlphaWood: public PickUp
{
 public:
    /// default constructor
    PickUpClearaudioAlphaWood() : PickUp("Clearaudio Alpha Wood", 
				    728, 0.429, 1e-18) {}
    /// destructor:
    virtual ~PickUpClearaudioAlphaWood() {}
};


/// Clearaudio Virtuoso Wood (data supplied by Frank Klemm).
class PickUpClearaudioVirtuosoWood: public PickUp
{
 public:
    /// default constructor
    PickUpClearaudioVirtuosoWood() : PickUp("Clearaudio Virtuoso Wood", 
				    737, 0.434, 1e-18) {}
    /// destructor:
    virtual ~PickUpClearaudioVirtuosoWood() {}
};


/// Clearaudio Gamma S Gold (data supplied by Frank Klemm).
class PickUpClearaudioGammaSGold: public PickUp
{
 public:
    /// default constructor
    PickUpClearaudioGammaSGold() : PickUp("Clearaudio Gamma S Gold", 
				    50, 0.0555e-3, 1e-18) {}
    /// destructor:
    virtual ~PickUpClearaudioGammaSGold() {}
};


/// Clearaudio Discovery (data supplied by Frank Klemm).
class PickUpClearaudioDiscovery: public PickUp
{
 public:
    /// default constructor
    PickUpClearaudioDiscovery() : PickUp("Clearaudio Discovery", 
				    49.8, 0.0548e-3, 1e-18) {}
    /// destructor:
    virtual ~PickUpClearaudioDiscovery() {}
};


/// Grado Platinum (data supplied by Frank Klemm).
class PickUpGradoPlatinum: public PickUp
{
 public:
    /// default constructor
    PickUpGradoPlatinum() : PickUp("Grado Platinum", 
				    2.35, 0.285e-3, 1e-18) {}
    /// destructor:
    virtual ~PickUpGradoPlatinum() {}
};


/// Grado Master (data supplied by Frank Klemm).
class PickUpGradoMaster: public PickUp
{
 public:
    /// default constructor
    PickUpGradoMaster() : PickUp("Grado Master", 
				    2.3, 0.278e-3, 1e-18) {}
    /// destructor:
    virtual ~PickUpGradoMaster() {}
};


/// Grado Reference (data supplied by Frank Klemm).
class PickUpGradoReference: public PickUp
{
 public:
    /// default constructor
    PickUpGradoReference() : PickUp("Grado Reference", 
				    2.3, 0.273e-3, 1e-18) {}
    /// destructor:
    virtual ~PickUpGradoReference() {}
};


/// Grado The Statement (data supplied by Frank Klemm).
class PickUpGradoStatement: public PickUp
{
 public:
    /// default constructor
    PickUpGradoStatement() : PickUp("Grado The Statement", 
				    3.2, 0.307-3, 1e-18) {}
    /// destructor:
    virtual ~PickUpGradoStatement() {}
};


END_NAMESPACE

#endif // ETECH_PICKUP_H









